Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(230)

Unified Diff: test/must_pub_get_test.dart

Issue 1956543002: Fix a lockfile freshness checking bug. (Closed) Base URL: git@github.com:dart-lang/pub.git@master
Patch Set: Code review changes Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « lib/src/package.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: test/must_pub_get_test.dart
diff --git a/test/must_pub_get_test.dart b/test/must_pub_get_test.dart
index 058ea89ae27e0681a29eb83ecb80902d80e91753..7a2136115fb93ac06c89150421e8a54d7df8cfe2 100644
--- a/test/must_pub_get_test.dart
+++ b/test/must_pub_get_test.dart
@@ -293,16 +293,20 @@ foo:http://example.com/
]).create();
d.dir(appPath, [
- d.appPubspec({"foo": {"path": "../foo"}})
- ]);
+ d.appPubspec({"bar": {"path": "../bar"}})
+ ]).create();
pubGet();
// Update foo's pubspec without touching the app's.
d.dir("bar", [
d.libPubspec("bar", "1.0.0", deps: {"foo": "2.0.0"})
]).create();
});
+
+ _requiresPubGet('${p.join('..', 'bar', 'pubspec.yaml')} has changed '
+ 'since the pubspec.lock file was generated, please run "pub get" '
+ 'again.');
});
});
« no previous file with comments | « lib/src/package.dart ('k') | no next file » | no next file with comments »
@@ -293,16 +293,20 @@ foo:http://example.com/
pubGet();
- // Update foo's pubspec without touching the app's.
+ // Update bar's pubspec without touching the app's.
d.dir("bar", [
d.libPubspec("bar", "1.0.0", deps: {"foo": "2.0.0"})

Powered by Google App Engine
This is Rietveld 408576698